@@ -4,6 +4,7 @@ from anytree import Node, RenderTree
                 |-h \n
                 |-i  \n
                 |-w  \n
+                |-c \n
                 |project \n
                     |-h \n
                     |-s \n
@@ -14,6 +15,7 @@ from anytree import Node, RenderTree
                     |-d \n
                 |education \n
                     |-h \n
+                    |-a \n
                     |-m \n
                     |-x \n
                     |-u \n
